@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2017-2022, QIIME 2 development team.
+# Copyright (c) 2017-2023, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -9,9 +9,10 @@
 from ._tabulate import tabulate
 from ._distance import distance_matrix
 from ._random import shuffle_groups
+from ._merge import merge
 from ._version import get_versions
 
 __version__ = get_versions()['version']
 del get_versions
 
-__all__ = ['tabulate', 'distance_matrix', 'shuffle_groups']
+__all__ = ['tabulate', 'distance_matrix', 'shuffle_groups', 'merge']
