@@ -1,28 +1,26 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2017-2022, QIIME 2 development team.
+# Copyright (c) 2017-2023, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
 # The full license is in the file LICENSE, distributed with this software.
 # ----------------------------------------------------------------------------
 
-import qiime2.plugin
-from qiime2.plugin import (MetadataColumn, Numeric, SemanticType, Categorical,
-                           Int, Str, ValidationError)
-import qiime2.plugin.model as model
-
-import q2_metadata
-
-from q2_metadata import tabulate, distance_matrix, shuffle_groups
+import pandas as pd
 from q2_types.distance_matrix import DistanceMatrix
 from q2_types.sample_data import SampleData
+from q2_types.metadata import ImmutableMetadata
+import qiime2.plugin
+from qiime2.plugin import (
+    Int, Categorical, MetadataColumn, model, Numeric, Plugin, SemanticType,
+    Str, Bool, Metadata, ValidationError,
+)
 
-import pandas as pd
+from . import tabulate, distance_matrix, shuffle_groups, merge, __version__
 
-
-plugin = qiime2.plugin.Plugin(
+plugin = Plugin(
     name='metadata',
-    version=q2_metadata.__version__,
+    version=__version__,
     website='https://github.com/qiime2/q2-metadata',
     package='q2_metadata',
     user_support_text=None,
@@ -116,15 +114,21 @@ plugin.methods.register_function(
     inputs={},
     parameters={'metadata': MetadataColumn[Categorical],
                 'n_columns': Int,
-                'column_name_prefix': Str,
-                'column_value_prefix': Str},
+                'md_column_name_prefix': Str,
+                'md_column_values_prefix': Str,
+                'encode_sample_size': Bool
+                },
     parameter_descriptions={
         'metadata': ('Categorical metadata column to shuffle.'),
         'n_columns': 'The number of shuffled metadata columns to create.',
-        'column_name_prefix': ('Prefix to use in naming the shuffled '
-                               'metadata columns.'),
-        'column_value_prefix': ('Prefix to use in naming the values in the '
-                                'shuffled metadata columns.')},
+        'md_column_name_prefix': ('Prefix to use in naming the shuffled '
+                                  'metadata columns.'),
+        'md_column_values_prefix': ('Prefix to use in naming the values in '
+                                    'the shuffled metadata columns.'),
+        'encode_sample_size': ('If true, the sample size of each metadata '
+                               'group will be appended to the shuffled '
+                               'metadata column values.'),
+        },
     output_descriptions={
         'shuffled_groups': 'Randomized metadata columns'},
     outputs=[('shuffled_groups', SampleData[ArtificialGrouping])],
@@ -138,3 +142,35 @@ plugin.methods.register_function(
                  'values with sample ids will be random. These data will be '
                  'written to an artifact that can be used as sample metadata.')
 )
+
+
+plugin.methods.register_function(
+    function=merge,
+    inputs={},
+    parameters={'metadata1': Metadata,
+                'metadata2': Metadata},
+    parameter_descriptions={
+        'metadata1': 'First metadata file to merge.',
+        'metadata2': 'Second metadata file to merge.'
+    },
+    outputs=[('merged_metadata', ImmutableMetadata)],
+    output_descriptions={
+        'merged_metadata': 'The merged metadata.'
+    },
+    name='Merge metadata',
+    description=('Merge metadata that contains overlapping ids or overlapping '
+                 'columns, but not both overlapping ids and overlapping '
+                 'columns. The result will be the union (i.e., outer join) '
+                 'of the ids and columns from the two metadata inputs.\n\n'
+                 'Attemping to merge metadata with both overlapping ids and '
+                 'overlapping columns will currently fail because we don\'t '
+                 'resolve conflicting column values for a sample. '
+                 'Merging metadata with neither overlapping ids or '
+                 'overlapping columns is possible with this action.\n\n'
+                 'To merge more than two metadata objects, run this command '
+                 'multiple times, iteratively using the output of the '
+                 'previous run as one of the metadata inputs.\n\n'
+                 'The output, an ImmutableMetadata artifact, can be used '
+                 'anywhere that a metadata file can be used, or can be '
+                 'exported to a metadata tsv file in the typical format.')
+)
